@@ -67,15 +67,15 @@ TQLayoutItem* FlowLayoutIterator::takeCurrent(){
 }
 
 
-FlowLayout::FlowLayout( TQWidget* parent, Qt::Orientation orientation, int border, int space, const char* name )
+FlowLayout::FlowLayout( TQWidget* parent, TQt::Orientation orientation, int border, int space, const char* name )
 	: TQLayout( parent, border, space, name ),
 	mOrientation(orientation), mLastItem(NULL){
 }
-FlowLayout::FlowLayout( TQLayout* parent, Qt::Orientation orientation, int space, const char* name )
+FlowLayout::FlowLayout( TQLayout* parent, TQt::Orientation orientation, int space, const char* name )
 	: TQLayout( parent, space, name ),
 	mOrientation(orientation), mLastItem(NULL){
 }
-FlowLayout::FlowLayout( Qt::Orientation orientation, int space, const char* name )
+FlowLayout::FlowLayout( TQt::Orientation orientation, int space, const char* name )
 	: TQLayout( space, name ),
 	mOrientation(orientation), mLastItem(NULL){
 }
@@ -102,7 +102,7 @@ void FlowLayout::addItem(TQLayoutItem* item){
 	// we are indirectly called from addSource. this
 	// is a hint for addSource, to let it know which item
 	// was added.
-	mLastItem = TQT_TQLAYOUTITEM(item);
+	mLastItem = item;
 }
 
 void FlowLayout::addSource(Source* src){
@@ -174,11 +174,11 @@ void FlowLayout::updatePositions(TDEConfig * inTDEConfig){
 }
 
 bool FlowLayout::hasHeightForWidth() const{
-	return mOrientation != Qt::Horizontal;
+	return mOrientation != TQt::Horizontal;
 }
 
 bool FlowLayout::hasWidthForHeight() const{
-	return mOrientation == Qt::Horizontal;
+	return mOrientation == TQt::Horizontal;
 }
 
 TQSize FlowLayout::sizeHint() const{
@@ -212,11 +212,11 @@ TQLayoutIterator FlowLayout::iterator(){
 	return TQLayoutIterator(new FlowLayoutIterator(&mLayoutItems));
 }
 
-Qt::Orientation FlowLayout::getOrientation() const{
+TQt::Orientation FlowLayout::getOrientation() const{
 	return mOrientation;
 }
 
-void FlowLayout::setOrientation(Qt::Orientation orientation){
+void FlowLayout::setOrientation(TQt::Orientation orientation){
 	mOrientation = orientation;
 }
 
@@ -226,7 +226,7 @@ void FlowLayout::setGeometry( const TQRect& rect ){
 }
 
 int FlowLayout::doLayout( const TQRect& rect, bool testonly ){
-	if(mOrientation == Qt::Horizontal)
+	if(mOrientation == TQt::Horizontal)
 		return doLayoutHorizontal(rect, testonly);
 	else
 		return doLayoutVertical(rect, testonly);
